"""scvi-tools Model classes for contrastive-VI."""
from .contrastive_vi import ContrastiveVIModel as ContrastiveVI

__all__ = ["ContrastiveVI"]
